Produces a plain-text message that a user without root access can send to their system administrator. The message lists missing system packages, which R packages need them, and a suggested install command.
Arguments
- x
A
sysreqr_planor package vector.- platform
Platform specification accepted by
resolve_platform().- ...
Passed to
check_packages()whenxis not a plan.
See also
Other commands:
dockerfile(),
github_actions(),
install_command()
Examples
plan <- check_packages("xml2", platform = "ubuntu-22.04")
cat(admin_request(plan))
#> Hello,
#>
#> Could you please install the following system packages on this server?
#>
#> libxml2-dev
#>
#> They are required to install or use these R packages:
#> xml2
#>
#> Suggested command:
#> sudo apt-get update
#> sudo apt-get install -y libxml2-dev
#>
#> Thank you.