Skip to contents

Reports whether a platform is currently served by Posit Package Manager and whether it has system requirement metadata and binary packages.

Usage

check_ppm(platform = NULL, base_url = ppm_default_base_url())

Arguments

platform

Platform specification accepted by resolve_platform().

base_url

Posit Package Manager base URL.

Value

A list with the matched platform and Package Manager status.

Examples

if (FALSE) { # \dontrun{
check_ppm("ubuntu-22.04")
check_ppm("fedora-40")
} # }